@@ -12,10 +12,12 @@ use crate::{
         flexbox::{TailWindFlexGrow, TailWindFlexShrink, TailWindOrder, TailwindFlex, TailwindFlexDirection, TailwindFlexWrap},
     },
     TailwindBorderCollapse, TailwindBoxDecorationBreak, TailwindBoxSizing, TailwindClear, TailwindColumns, TailwindContainer,
-    TailwindDisplay, TailwindFloat, TailwindFontFamily, TailwindFontSize, TailwindFontSmoothing, TailwindFontWeight,
-    TailwindIsolation, TailwindPosition, TailwindScreenReader, TailwindSizing, TailwindSpacing, TailwindTextAlignment,
-    TailwindTextColor, TailwindVisibility,
+    TailwindDisplay, TailwindDivideStyle, TailwindFloat, TailwindFontFamily, TailwindFontSize, TailwindFontSmoothing,
+    TailwindFontStyle, TailwindFontWeight, TailwindIsolation, TailwindLeading, TailwindOutlineStyle, TailwindPosition,
+    TailwindRingOffsetWidth, TailwindScreenReader, TailwindShadow, TailwindSizing, TailwindSpacing, TailwindTextAlignment,
+    TailwindTextColor, TailwindTracking, TailwindUnderlineOffset, TailwindVisibility,
 };
+use log::error;
 use std::{
     fmt::{Display, Formatter, Write},
     str::FromStr,
@@ -96,7 +98,8 @@ impl TailwindInstance for AstStyle {
         match self.get_instance() {
             Ok(o) => out.extend(o.attributes(ctx)),
             Err(e) => {
-                println!("{:?}", e)
+                #[cfg(debug_assertions)]
+                error!("{:?}", e)
             }
         }
         out
@@ -175,15 +178,14 @@ impl AstStyle {
             ["text", rest @ ..] => Self::text_adaptor(rest, arbitrary)?,
             ["antialiased"] => TailwindFontSmoothing::new(false).boxed(),
             ["subpixel", "antialiased"] => TailwindFontSmoothing::new(true).boxed(),
-            ["italic"] => todo!(),
-            ["not", "italic"] => todo!(),
-            // TODO:https://tailwindcss.com/docs/font-variant-numeric
-            ["tracking", rest @ ..] => todo!(),
-            ["leading", rest @ ..] => todo!(),
+            ["italic"] => TailwindFontStyle::Italic.boxed(),
+            ["not", "italic"] => TailwindFontStyle::Normal.boxed(),
+            // TODO: https://tailwindcss.com/docs/font-variant-numeric
+            ["tracking", rest @ ..] => TailwindTracking::parse(rest, arbitrary)?.boxed(),
+            ["leading", rest @ ..] => TailwindLeading::parse(rest, arbitrary)?.boxed(),
             ["list", rest @ ..] => Self::list_adaptor(rest, arbitrary)?,
-            ["text", alignment @ ("text" | "serif" | "mono")] => todo!(),
             // TODO:https://tailwindcss.com/docs/font-variant-numeric
-            ["underline", rest @ ..] => todo!(),
+            ["underline", "offset", rest @ ..] => TailwindUnderlineOffset::parse(rest, arbitrary)?.boxed(),
             ["decoration", rest @ ..] => todo!(),
             // Typography System Extension
             ["prose"] => todo!(),
@@ -208,7 +210,7 @@ impl AstStyle {
             ["brightness", rest @ ..] => TailwindBrightness::parse(rest, arbitrary)?.boxed(),
             ["contrast", rest @ ..] => todo!(),
 
-            ["drop", "shadow", rest @ ..] => todo!(),
+            ["drop", "shadow", rest @ ..] => TailwindShadow::parse_drop(rest, arbitrary)?.boxed(),
 
             ["grayscale", rest @ ..] => todo!(),
             ["backdrop", rest @ ..] => todo!(),
@@ -219,7 +221,6 @@ impl AstStyle {
             ["duration", rest @ ..] => todo!(),
             ["ease", rest @ ..] => todo!(),
             ["delay", rest @ ..] => todo!(),
-
             ["animate", rest @ ..] => todo!(),
             ["ease", rest @ ..] => todo!(),
             ["delay", rest @ ..] => todo!(),
@@ -283,11 +284,11 @@ impl AstStyle {
             ["y"] => todo!(),
             ["y", n] => todo!(),
             // https://tailwindcss.com/docs/divide-style
-            ["solid"] => todo!(),
-            ["dashed"] => todo!(),
-            ["dotted"] => todo!(),
-            ["double"] => todo!(),
-            ["none"] => todo!(),
+            ["solid"] => TailwindDivideStyle::Solid.boxed(),
+            ["dashed"] => TailwindDivideStyle::Dashed.boxed(),
+            ["dotted"] => TailwindDivideStyle::Dotted.boxed(),
+            ["double"] => TailwindDivideStyle::Double.boxed(),
+            ["none"] => TailwindDivideStyle::None.boxed(),
             // https://tailwindcss.com/docs/divide-color
             _ => return syntax_error!("Unknown divide instructions: {}", str.join("-")),
         };
@@ -296,17 +297,17 @@ impl AstStyle {
     #[inline]
     fn outline_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            // https://tailwindcss.com/docs/outline-width
-            [n] => todo!(),
             // https://tailwindcss.com/docs/outline-style
             [] => todo!(),
-            ["none"] => todo!(),
-            ["dashed"] => todo!(),
-            ["dotted"] => todo!(),
-            ["double"] => todo!(),
-            ["hidden"] => todo!(),
+            ["none"] => TailwindOutlineStyle::None.boxed(),
+            ["dashed"] => TailwindOutlineStyle::Dashed.boxed(),
+            ["dotted"] => TailwindOutlineStyle::Dotted.boxed(),
+            ["double"] => TailwindOutlineStyle::Double.boxed(),
+            ["hidden"] => TailwindOutlineStyle::Hidden.boxed(),
             // https://tailwindcss.com/docs/outline-offset
             ["offset", n] => todo!(),
+            // https://tailwindcss.com/docs/outline-width
+            [n] => todo!(),
             _ => return syntax_error!("Unknown outline instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -314,7 +315,8 @@ impl AstStyle {
     #[inline]
     fn ring_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            // https://tailwindcss.com/docs/float
+            // https://tailwindcss.com/docs/ring-offset-width
+            ["offset", rest @ ..] => TailwindRingOffsetWidth::parse(rest, arbitrary)?.boxed(),
             _ => return syntax_error!("Unknown ring instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -323,6 +325,7 @@ impl AstStyle {
     fn shadow_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/box-shadow
+            [] => TailwindShadow::parse_arbitrary(arbitrary)?.boxed(),
             ["sm"] => todo!(),
             // https://tailwindcss.com/docs/box-shadow-color
             _ => return syntax_error!("Unknown shadow instructions: {}", str.join("-")),
@@ -436,9 +439,7 @@ impl AstStyle {
     fn font_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/float
-            ["sans"] => TailwindFontFamily::Sans.boxed(),
-            ["serif"] => TailwindFontFamily::Sans.boxed(),
-            ["mono"] => TailwindFontFamily::Sans.boxed(),
+            [s @ ("sans" | "serif" | "mono")] => TailwindFontFamily::new(s).boxed(),
             // https://tailwindcss.com/docs/font-size
             ["xs"] => TailwindFontSize::new(0.75, 1.0).boxed(),
             ["sm"] => TailwindFontSize::new(0.75, 1.0).boxed(),
