@@ -1,7 +1,7 @@
-mod builder;
+mod display;
 mod parser;
 
-use crate::{ColorResolver, TailwindInstance};
+use super::*;
 
 ///
 #[derive(Copy, Clone, Debug)]
@@ -44,7 +44,7 @@ pub enum TailwindOutlineStyle {
     Dashed,
     Dotted,
     Double,
-    // Hidden,
+    Hidden,
 }
 
 ///
